Description: Fix cursor recapturing in track panel sliders
 wxWidgets 3.0 has added a lot of asserts to detect incorrect usage
 of its APIs. Now capturing the cursor, when it's already captured,
 throughs an assertion failure. This can be the case in the track
 panel sliders because the sliders capture the cursor themselves
 (because they are also used in other places outside the track panel,
 where this is actually necessary), but the track panel also manages
 the cursor capturing because it needs it for other operations.
 Fix the recapturing problem by letting the sliders capture the cursor
 only if necessary.
Author: Martin SteghÃ¶fer <martin@steghoefer.eu>
Bug-Debian: https://bugs.debian.org/

--- a/src/widgets/ASlider.cpp
+++ b/src/widgets/ASlider.cpp
@@ -1070,7 +1070,9 @@ void LWSlider::OnMouseEvent(wxMouseEvent & event)
                event.ShiftDown());
       }
 
-      mParent->CaptureMouse();
+      if (!mParent->HasCapture()) {
+         mParent->CaptureMouse();
+      }
       // wxSetCursor(wxCURSOR_BLANK);
       ((TipPanel*)LWSlider::sharedTipPanel)->SetTargetParent(mParent);
       FormatPopWin();
